--------------------------------------------------------------------------------------------------------------
--
-- Module     : SIMS Database SQL Server 2005
-- Platform   : SIMS
-- Area       : DBUpgrade Database Patch
-- Copyright  : (c) Capita Education Services 2005-2009
--            : This code has been written by Capita Education Services for use within its own SIMS systems.
--            : It is unpublished proprietary work, and as such it is illegal for it to be reproduced by any
--            : means or used without the express written permission of Capita Education Services.
-- Patch ID   : 17689
--
--------------------------------------------------------------------------------------------------------------

-- Check this is within the acceptible range
  IF NOT EXISTS(
	SELECT 1 
	FROM	sims.db_version_info
	WHERE	schema_version BETWEEN '3.61.861' AND '3.61.999')
  BEGIN
    DECLARE @error_msg2 VARCHAR(100)
    SET @error_msg2 = CHAR(10) + CHAR(13) + 'This patch is not applicable to this database version.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg2, 18, 1)
  END

GO
-- START PATCH CODE



-- START PATCH SCRIPT 1

/*
	Created By  : Arun Sutar
	Date		: 03/12/2012
	Reason		: [PRB3058] - After upgrade to Autumn Release(6.92) extra time was missing in Seating Organisation for candidates.
					 Patch will show the Extra Time for the candidate Which were given in Previous Release. 
					 
	Below are Test Cases :
	
	A. Extra Time for Candidate will display only who have extra time with no special arrangement as 'Extra time without Special Arrangement'
	B. Extra Time will dispaly candidates having extra time with few or all special arrangement
	C. No Extra Time will display candidate having only Special Arrangement
*/

SET nocount ON

Declare @ExtrTimeNoSpcArrng int

If not exists(select * From sims.exam_special_arrangements where description='Extra time without Special Arrangement') 
	Insert into sims.exam_special_arrangements(description,extra_time) values('Extra time without Special Arrangement',1)

select @ExtrTimeNoSpcArrng = special_arrangement_id from sims.exam_special_arrangements where description='Extra time without Special Arrangement'	

----- insert candidate only who have extra time with no special arrangement
Insert into sims.exam_candidate_special_arrangements(candidate_id,special_arrangement_id,extra_time)
select distinct candidate_id,@ExtrTimeNoSpcArrng,1 from sims.exam_seat_allocation a where extra_time_percent >0
and not exists (select 1 from sims.exam_candidate_special_arrangements b where b.candidate_id=a.candidate_id)

--- Set special consideration to True who have extra time with no special arrangement in Candidate Table
Update s set special_consideration=1
from sims.exam_candidate s inner join
(
	select distinct candidate_id from sims.exam_seat_allocation a 
	where extra_time_percent >0
	and exists(select 1 from sims.exam_candidate_special_arrangements b					
					where b.candidate_id=a.candidate_id and b.special_arrangement_id =@ExtrTimeNoSpcArrng)
) p on s.candidate_id = p.candidate_id


GO


-- END PATCH SCRIPT 1
GO


-- END PATCH CODE



-- Record that this patch has been updated
INSERT INTO sims.db_update_log
(
	patch_id,
	update_id,
	successful,
	description,
	update_type,
	date_applied
)
VALUES
(
	17689,
	1,
	'T',
	'[OD]: Fix as Extra Time for Candidate will display only who have extra time with no special arrangement As ''Extra time without Special Arrangement'' for issue reported in Autumn release (6.92)',
	'U',
	GetDate()
)

